*********
Changelog
*********

**2017-##-## Version 0.8.0**
  - New MySmile API v2 based on Django Rest Framework 3
  - Updated docs

**2016-12-18 Version 0.7.2**
  - Removed database from repository. #14
  - Fixed turning off language in admin. #15
  - Added 404 page language alternative for inner page. #16
  - Updated docs
  - Added Docker
  - Upgraded Django 1.8.17

**2015-10-15 Version 0.7.1**
  - Added IMAGE_AUTOSCALE preference to admin panel
  - Protected admin login page from brute-force attack
  - Added "view on site" button to admin panel
  - Removed database from repository
  - Updated docs

**2015-07-13 Version 0.7.0**
  - Optimized DB queries
  - Added theme switcher in the admin panel
  - Added MySmile version notification in the admin panel
  - Integrated Bower
  - Updated docs

**2015-05-10 Version 0.6.2**
  - Fixed language flags in the admin panel
  - Updated settings
  - Refactored email spam protection
  - Updated code with PEP8 style
  - Made images responsive
  - Django 1.8 support!

**2015-04-05 Version 0.6.1**
  - Added new design theme based on Bootstrap 3
  - Renamed old design as a classic theme
  - Added version number on the admin panel
  - Bug fixed images are removed after page was deleted
  - Bug fixed change language in admin panel

**2015-03-01 Version 0.6.0**
  - Added global setting quality for uploaded images
  - Added description to image preview in page list table into admin
  - Added full cache pages. It's auto renewal when detect changes through admin panel
  - Bug fixed hide language flag if only one is provided
  
**2015-02-09 Version 0.5.3**
  - Added compressor for css and js
  - Integrated Travis CI and Coveralls
  - Fixed delete images from server through admin panel
  - Updated docs
  - Django 1.7 support!

**2014-10-13 Version 0.5.2**
  - Added Responsible Design
  - Refactored code to support themes

**2014-08-18 Version 0.5.1**
  - Added ability to select the language in the admin panel
  - Added flexible 404 error page
  - Updated docs

**2014-07-31 Version 0.5.0**
  - E-mail address was converted to image to protect against spam bots
  - Improved image preview in admin panel
  - Applied class based view (CBV)
  - Added functionality to edit config parameters by admin panel
  - Implemented new page types: "api page" and "api & menu page"
  - Updated docs

**2014-05-16 Version 0.4.1**
  - Added REST_API setting parameter to turn on/off REST API
  - Added autocomplete sortorder-field for new pages
  - Easy to switch between local and production versions with a single parameter DEBUG
  - Changed response of contents resource of REST API
  - Updated layout if project has only one language  then flag icon is not displayed
  - Improved separation of project settings 
  - Bug fixed of sitemap generation

**2014-04-01 Version 0.4.0**
  - REST API and documentation for them
  - Added REST API Client for PHP
  - Improved HTML5 support

**2014-02-15 Version 0.3.0**
  - Added Unit tests
  - Used sphinx for docs
  - Fixed incorrect behavior of the dynamic menu
  - Updated settings
  - Changed project structure

**2013-11-23 Version 0.2.2**
  - Add apple-touch-icon-precomposed.png
  - Improved admin localize system
  - Django 1.6 support!

**2013-09-27 Version 0.2.1**
  - Improved Admin panel
  - Code was refactored
  - Last realise for Django 1.5x series

**2013-09-19  Version 0.2.0**
  - Fixed some bugs
  - Improved main menu

**2013-08-18  Version 0.2.0b**
  - Added new page type "inner_page"
  - Integrated videos from YouTube
  - Improved usability of admin panel
  - Config parameter MAX_NUM_PAGE was temporary disabled

**2013-05-15  Version 0.1.0**
  - Fixed one bug in Sitemap.xml 
  - Fixed some bugs and inconveniences

**2013-04-19  Version 0.1.0b**
  - Beta version was launched

**2012-12-01  Version 0.0.1**
  - Created technical documentation
  - Made design
